@@ -1,67 +1,70 @@
 var languageNames = {
 "en-US": "Inglés (EE. UU.)",
+"sq": "Albanés",
 "am": "Amárico",
 "ar": "Árabe",
 "ast": "Asturiano",
-"bg": "Búlgaro",
 "bn": "Bengalí",
 "bn-IN": "Bengalí (India)",
-"bo": "Tibetano",
 "bs": "Bosnio",
+"bg": "Búlgaro",
 "ca": "Catalán",
-"ca-valencia": "Catalán (Valencia)",
+"ca-valencia": "Catalan (Valencia)",
+"zh-CN": "Chino (simplificado)",
+"zh-TW": "Chino (tradicional)",
+"hr": "Croata",
 "cs": "Checo",
 "da": "Danés",
-"de": "Alemán",
+"nl": "Neerlandés",
 "dz": "Butanés",
-"el": "Griego",
 "en-GB": "Inglés (R. U.)",
 "en-ZA": "Inglés (Sudáf.)",
 "eo": "Esperanto",
-"es": "Español",
 "et": "Estonio",
 "eu": "Vasco",
 "fi": "Finés",
 "fr": "Francés",
 "gl": "Gallego",
+"ka": "Georgiano",
+"de": "Alemán",
+"el": "Griego",
 "gu": "Guyaratí",
 "he": "Hebreo",
 "hi": "Hindi",
-"hr": "Croata",
 "hu": "Húngaro",
 "id": "Indonesio",
 "is": "Islandés",
 "it": "Italiano",
 "ja": "Japonés",
-"ka": "Georgiano",
 "km": "Camboyano",
 "ko": "Coreano",
 "lo": "Lao",
-"lt": "Lituano",
 "lv": "Letón",
+"lt": "Lituano",
 "mk": "Macedonio",
-"nb": "Noruego bokmål",
 "ne": "Nepalí",
-"nl": "Neerlandés",
 "nn": "Noruego nynorsk",
+"nb": "Noruego bokmål",
 "om": "Oromo",
 "pl": "Polaco",
 "pt": "Portugués",
-"pt-BR": "Portugués (Brasil)",
+"pt-BR": "Portuguese (Brazil)",
 "ro": "Rumano",
 "ru": "Ruso",
-"si": "Cingalés",
 "sid": "Sidamo",
+"si": "Cingalés",
 "sk": "Eslovaco",
 "sl": "Esloveno",
-"sq": "Albanés",
+"dsb": "Sorbian (Lower)",
+"hsb": "Sorbian (Upper)",
+"es": "Español",
 "sv": "Sueco",
-"ta": "Tamil",
 "tg": "Tayiko",
+"ta": "Tamil",
+"bo": "Tibetano",
+"tl": "Tagalo",
 "tr": "Turco",
 "ug": "Uigur",
 "uk": "Ucraniano",
 "vi": "Vietnamita",
-"zh-CN": "Chino (simplificado)",
-"zh-TW": "Chino (tradicional)",
 };
